Documentation
¶
Index ¶
- func GenerateTaskDefinition(input *GenerateTaskDefinitionInput, client *ecs.Client, logger *log.Entry) (*types.TaskDefinition, bool, error)
- type CapacityProviderStrategy
- type Config
- type GenerateTaskDefinitionInput
- type NetworkConfiguration
- type Service
- type Status
- type Task
- type TaskStage
- type Tasks
- type VpcConfiguration
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateTaskDefinition ¶
func GenerateTaskDefinition(input *GenerateTaskDefinitionInput, client *ecs.Client, logger *log.Entry) (*types.TaskDefinition, bool, error)
Types ¶
type Config ¶
type Config struct {
Version string `mapstructure:"version" validate:"required,oneof=v1"`
Cluster string `mapstructure:"cluster" validate:"required"`
Services []Service `mapstructure:"services" validate:"omitempty,dive"`
Tasks Tasks `mapstructure:"tasks" validate:"omitempty,dive"`
}
func (*Config) DeployServices ¶
func (*Config) DeployTasks ¶
type GenerateTaskDefinitionInput ¶
type GenerateTaskDefinitionInput struct {
// The docker image tag to use when updating the container image.
//
// This member is required.
ImageTag *string
// The task definition to use as a foundation for a new task definition.
// Could be the family for the latest ACTIVE revision, family and revision
// (family:revision) for a specific revision in the family, or full Amazon
// Resource Name (ARN) of the task definition.
//
// This member is required.
TaskDefinition *string
// Container mapping for easy lookup of containers that should be updated,
// basically create a map with the container name as the key and `true` as
// the value.
//
// This member is required.
UpdateableContainers map[string]bool
}
type NetworkConfiguration ¶
type NetworkConfiguration struct {
VpcConfiguration VpcConfiguration `mapstructure:"vpc_configuration" validate:"required,dive"`
}
type Task ¶
type Task struct {
Family string `mapstructure:"family" validate:"required"`
Containers []string `mapstructure:"containers" validate:"required,min=1,dive"`
Count int32 `mapstructure:"count" validate:"required,min=1,max=10"`
CapacityProviderStrategies []CapacityProviderStrategy `mapstructure:"capacity_provider_strategies" validate:"omitempty,max=6,dive"`
LaunchType *string `mapstructure:"launch_type" validate:"omitempty,oneof=ec2 fargate external"`
NetworkConfiguration *NetworkConfiguration `mapstructure:"network_configuration" validate:"omitempty,dive"`
}
type VpcConfiguration ¶
Click to show internal directories.
Click to hide internal directories.